=================
pip-compile-multi
=================

.. image:: https://badge.fury.io/py/pip-compile-multi.png
    :target: https://badge.fury.io/py/pip-compile-multi

.. image:: https://github.com/peterdemin/pip-compile-multi/actions/workflows/python38.yml/badge.svg
    :target: https://github.com/peterdemin/pip-compile-multi/actions/workflows/python38.yml

.. image:: https://img.shields.io/pypi/pyversions/pip-compile-multi.svg
    :target: https://pypi.python.org/pypi/pip-compile-multi

`Docs <https://pip-compile-multi.readthedocs.io/en/latest/>`_

Compile multiple requirements files to lock dependency versions.

Install
-------

.. code-block:: shell

    pip install pip-compile-multi

Run
----

.. code-block:: shell

    pip-compile-multi


Trusted by
----------

|uber| |mozilla| |twitter|

|nih| |skydio| |pallets|

|moveworks|


Read the Docs
-------------

* `Why use pip-compile-multi <https://pip-compile-multi.readthedocs.io/en/latest/why.html>`_
* `How to start using pip-compile-multi <https://pip-compile-multi.readthedocs.io/en/latest/migration.html>`_
* `List of features <https://pip-compile-multi.readthedocs.io/en/latest/features.html>`_

.. |nih| image:: docs/NIH_logo.svg
   :width: 200 px
   :height: 200 px
   :target: https://www.nih.gov/

.. |uber| image:: docs/Uber_Logo_Black_RGB.svg
   :width: 200 px
   :height: 200 px
   :target: https://www.uber.com/

.. |mozilla| image:: docs/moz-logo-bw-rgb.svg
   :width: 200 px
   :height: 200 px
   :target: https://www.mozilla.org/

.. |skydio| image:: docs/skydio-logo-black.svg
   :width: 200 px
   :height: 200 px
   :target: https://www.skydio.com/

.. |pallets| image:: docs/pallets.png
   :width: 200 px
   :height: 200 px
   :target: https://palletsprojects.com/

.. |twitter| image:: docs/twitter_logo.svg
   :width: 200 px
   :height: 200 px
   :target: https://twitter.com/

.. |moveworks| image:: docs/Moveworks.svg
   :width: 400 px
   :height: 200 px
   :target: https://moveworks.com/
